#! -*- coding: utf-8 -*-

import autocomplete_light

from django.contrib.auth import get_user_model
from django.utils.translation import ugettext_lazy as _

from jmb.core.utils.autocomplete import DynamicAutocompleteModelBase

from thux.organization import models

autocomplete_light.register(
    models.Organization, search_fields=['code', 'name', 'vat_number'],
)


#: user autocompletes
class UserAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['username', 'last_name', 'first_name', 'email']
    choices = get_user_model().objects.all()
    model = get_user_model()
    autocomplete_js_attributes = {
        'minimum_characters': 0
    }
autocomplete_light.register(UserAutocomplete, name="User")


class OrganizationGroupAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['name', ]
    choices = models.OrganizationGroup.objects
    model = models.OrganizationGroup
    attrs = {
        'data-autocomplete-minimum-characters': 0,
        'placeholder': _('type some text to search'),
    }
autocomplete_light.register(OrganizationGroupAutocomplete, name='OrganizationGroup')


#: organization autocompletes
class OrganizationAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['code', 'name']
    choices = models.Organization.objects
    attrs = {
        'data-autocomplete-minimum-characters': 0,
        'placeholder': _('type some text to search'),
    }
    # autocomplete_js_attributes = {'placeholder': _('organization'), }
    model = models.Organization
autocomplete_light.register(OrganizationAutocomplete, name="Organization")


class OwnerOrganizationAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['code', 'name']
    choices = models.OwnerOrganization.objects.filter()
    autocomplete_js_attributes = {'placeholder': _('owner organization'), 'minimum_characters': 0}
    model = models.OwnerOrganization
autocomplete_light.register(OwnerOrganizationAutocomplete, name="OwnerOrganization")


class CustomerOrganizationAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['code', 'name']
    choices = models.CustomerOrganization.objects.filter()
    autocomplete_js_attributes = {'placeholder': _('customer organization'), 'minimum_characters': 0}
    model = models.CustomerOrganization
autocomplete_light.register(CustomerOrganizationAutocomplete, name="CustomerOrganization")


class SupplierOrganizationAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['code', 'name']
    choices = models.SupplierOrganization.objects.filter()
    autocomplete_js_attributes = {'placeholder': _('supplier organization'), 'minimum_characters': 0}
    model = models.SupplierOrganization
autocomplete_light.register(SupplierOrganizationAutocomplete, name="SupplierOrganization")


#: contact autocomplete
class ContactAutocomplete(DynamicAutocompleteModelBase):
    search_fields = ['last_name', 'first_name']
    choices = models.Contact.objects.all()
    autocomplete_js_attributes = {'placeholder': _('contact'), }
    model = models.Contact
autocomplete_light.register(ContactAutocomplete, name="Contact")


class OwnerContactAutocomplete(DynamicAutocompleteModelBase):
    attrs = {}
    filters = {'organization_id': '#id_organization'}
    search_fields = ['last_name', 'first_name']
    choices = models.OwnerContact.objects.filter()
    autocomplete_js_attributes = {'placeholder': _('owner contact'), 'minimum_characters': 0}
    model = models.OwnerContact
autocomplete_light.register(OwnerContactAutocomplete, name="OwnerContact")


class CustomerContactAutocomplete(DynamicAutocompleteModelBase):
    attrs = {}
    filters = {'organization_id': '#id_organization'}
    search_fields = ['last_name', 'first_name']
    choices = models.CustomerContact.objects.filter()
    autocomplete_js_attributes = {'placeholder': _('customer contact'), 'minimum_characters': 0}
    model = models.CustomerContact
autocomplete_light.register(CustomerContactAutocomplete, name="CustomerContact")


class SupplierContactAutocomplete(DynamicAutocompleteModelBase):
    attrs = {}
    filters = {'organization_id': '#id_organization'}
    search_fields = ['last_name', 'first_name']
    choices = models.SupplierContact.objects.filter()
    autocomplete_js_attributes = {'placeholder': _('supplier contact'), 'minimum_characters': 0}
    model = models.SupplierContact
autocomplete_light.register(SupplierContactAutocomplete, name="SupplierContact")


class WorkerContactAutocomplete(DynamicAutocompleteModelBase):
    attrs = {}
    filters = {'organization_id': '#id_organization'}
    search_fields = ['last_name', 'first_name']
    choices = models.WorkerContact.objects.filter()
    autocomplete_js_attributes = {'placeholder': _('worker contact'), 'minimum_characters': 0}
    model = models.WorkerContact
autocomplete_light.register(WorkerContactAutocomplete, name="WorkerContact")
