# -*- coding: utf-8 -*-

from rest_framework import generics

from thux.api.views import QuerysetMixin
from thux.api.permissions import ThuxModelPermissions

from .. import models
from . import serializers


class OrganizationAddressList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationAddress.objects.all()
    serializer_class = serializers.OrganizationAddressSerializer


class OrganizationAddressRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationAddress.objects.all()
    serializer_class = serializers.OrganizationAddressSerializer


class OrganizationAddressCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationAddress.objects.all()
    serializer_class = serializers.OrganizationAddressSerializerCreate


class OrganizationAddressUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationAddress.objects.all()
    serializer_class = serializers.OrganizationAddressSerializerUpdate
    
    
class OrganizationList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Organization.objects.all()
    serializer_class = serializers.OrganizationSerializer


class OrganizationRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Organization.objects.all()
    serializer_class = serializers.OrganizationSerializer


class OrganizationCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Organization.objects.all()
    serializer_class = serializers.OrganizationSerializerCreate


class OrganizationUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Organization.objects.all()
    serializer_class = serializers.OrganizationSerializerUpdate
    
    
class OwnerOrganizationList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OwnerOrganization.objects.all()
    serializer_class = serializers.OwnerOrganizationSerializer


class OwnerOrganizationRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OwnerOrganization.objects.all()
    serializer_class = serializers.OwnerOrganizationSerializer


class OwnerOrganizationCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OwnerOrganization.objects.all()
    serializer_class = serializers.OwnerOrganizationSerializerCreate


class OwnerOrganizationUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OwnerOrganization.objects.all()
    serializer_class = serializers.OwnerOrganizationSerializerUpdate


class CustomerOrganizationList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.CustomerOrganization.objects.all()
    serializer_class = serializers.CustomerOrganizationSerializer


class CustomerOrganizationRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.CustomerOrganization.objects.all()
    serializer_class = serializers.CustomerOrganizationSerializer


class CustomerOrganizationCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.CustomerOrganization.objects.all()
    serializer_class = serializers.CustomerOrganizationSerializerCreate


class CustomerOrganizationUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.CustomerOrganization.objects.all()
    serializer_class = serializers.CustomerOrganizationSerializerUpdate


class SupplierOrganizationList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.SupplierOrganization.objects.all().prefetch_related('organization_groups')
    serializer_class = serializers.SupplierOrganizationSerializer


class SupplierOrganizationRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.SupplierOrganization.objects.all()
    serializer_class = serializers.SupplierOrganizationSerializer


class SupplierOrganizationCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.SupplierOrganization.objects.all()
    serializer_class = serializers.SupplierOrganizationSerializerCreate


class SupplierOrganizationUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.SupplierOrganization.objects.all()
    serializer_class = serializers.SupplierOrganizationSerializerUpdate


class VectorOrganizationList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.VectorOrganization.objects.all()
    serializer_class = serializers.VectorOrganizationSerializer


class VectorOrganizationRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.VectorOrganization.objects.all()
    serializer_class = serializers.VectorOrganizationSerializer


class VectorOrganizationCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.VectorOrganization.objects.all()
    serializer_class = serializers.VectorOrganizationSerializerCreate


class VectorOrganizationUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.VectorOrganization.objects.all()
    serializer_class = serializers.VectorOrganizationSerializerUpdate


class OrganizationGroupList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationGroup.objects.all()
    serializer_class = serializers.OrganizationGroupSerializer


class OrganizationGroupRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationGroup.objects.all()
    serializer_class = serializers.OrganizationGroupSerializer


class OrganizationGroupCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationGroup.objects.all()
    serializer_class = serializers.OrganizationGroupSerializerCreate


class OrganizationGroupUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationGroup.objects.all()
    serializer_class = serializers.OrganizationGroupSerializerUpdate


class OrganizationFormList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationForm.objects.all()
    serializer_class = serializers.OrganizationFormSerializer


class OrganizationFormRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationForm.objects.all()
    serializer_class = serializers.OrganizationFormSerializer


class OrganizationFormCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationForm.objects.all()
    serializer_class = serializers.OrganizationFormSerializerCreate


class OrganizationFormUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationForm.objects.all()
    serializer_class = serializers.OrganizationFormSerializerUpdate


class OrganizationTypeList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationType.objects.all()
    serializer_class = serializers.OrganizationTypeSerializer


class OrganizationTypeRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationType.objects.all()
    serializer_class = serializers.OrganizationTypeSerializer


class OrganizationTypeCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationType.objects.all()
    serializer_class = serializers.OrganizationTypeSerializerCreate


class OrganizationTypeUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationType.objects.all()
    serializer_class = serializers.OrganizationTypeSerializerUpdate


class FieldList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Field.objects.all()
    serializer_class = serializers.FieldSerializer


class FieldRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Field.objects.all()
    serializer_class = serializers.FieldSerializer


class FieldCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Field.objects.all()
    serializer_class = serializers.FieldSerializerCreate


class FieldUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Field.objects.all()
    serializer_class = serializers.FieldSerializerUpdate


class ContactRoleList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ContactRole.objects.all()
    serializer_class = serializers.ContactRoleSerializer


class ContactRoleRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ContactRole.objects.all()
    serializer_class = serializers.ContactRoleSerializer


class ContactRoleCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ContactRole.objects.all()
    serializer_class = serializers.ContactRoleSerializerCreate


class ContactRoleUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ContactRole.objects.all()
    serializer_class = serializers.ContactRoleSerializerUpdate


class ContactTitleList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ContactTitle.objects.all()
    serializer_class = serializers.ContactTitleSerializer


class ContactTitleRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ContactTitle.objects.all()
    serializer_class = serializers.ContactTitleSerializer


class ContactTitleCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ContactTitle.objects.all()
    serializer_class = serializers.ContactTitleSerializerCreate


class ContactTitleUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.ContactTitle.objects.all()
    serializer_class = serializers.ContactTitleSerializerUpdate


class ContactList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Contact.objects.all()
    serializer_class = serializers.ContactSerializer


class ContactRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Contact.objects.all()
    serializer_class = serializers.ContactSerializer


class ContactCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Contact.objects.all()
    serializer_class = serializers.ContactSerializerCreate


class ContactUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Contact.objects.all()
    serializer_class = serializers.ContactSerializerUpdate


class OwnerContactList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OwnerContact.objects.all()
    serializer_class = serializers.OwnerContactSerializer


class OwnerContactRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OwnerContact.objects.all()
    serializer_class = serializers.OwnerContactSerializer


class OwnerContactCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OwnerContact.objects.all()
    serializer_class = serializers.OwnerContactSerializerCreate


class OwnerContactUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OwnerContact.objects.all()
    serializer_class = serializers.OwnerContactSerializerUpdate


class CustomerContactList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.CustomerContact.objects.all()
    serializer_class = serializers.CustomerContactSerializer


class CustomerContactRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.CustomerContact.objects.all()
    serializer_class = serializers.CustomerContactSerializer


class CustomerContactCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.CustomerContact.objects.all()
    serializer_class = serializers.CustomerContactSerializerCreate


class CustomerContactUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.CustomerContact.objects.all()
    serializer_class = serializers.CustomerContactSerializerUpdate


class SupplierContactList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.SupplierContact.objects.all()
    serializer_class = serializers.SupplierContactSerializer


class SupplierContactRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.SupplierContact.objects.all()
    serializer_class = serializers.SupplierContactSerializer


class SupplierContactCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.SupplierContact.objects.all()
    serializer_class = serializers.SupplierContactSerializerCreate


class SupplierContactUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.SupplierContact.objects.all()
    serializer_class = serializers.SupplierContactSerializerUpdate


class WorkerContactList(QuerysetMixin, generics.ListAPIView):
    queryset = models.WorkerContact.objects.all()
    serializer_class = serializers.WorkerContactSerializer


class WorkerContactRetrieve(generics.RetrieveAPIView):
    queryset = models.WorkerContact.objects.all()
    serializer_class = serializers.WorkerContactSerializer


class WorkerContactCreate(generics.CreateAPIView):
    queryset = models.WorkerContact.objects.all()
    serializer_class = serializers.WorkerContactSerializerCreate


class WorkerContactUpdate(generics.UpdateAPIView):
    queryset = models.WorkerContact.objects.all()
    serializer_class = serializers.WorkerContactSerializerUpdate


class VectorContactList(QuerysetMixin, generics.ListAPIView):
    queryset = models.VectorContact.objects.all()
    serializer_class = serializers.VectorContactSerializer


class VectorContactRetrieve(generics.RetrieveAPIView):
    queryset = models.VectorContact.objects.all()
    serializer_class = serializers.VectorContactSerializer


class VectorContactCreate(generics.CreateAPIView):
    queryset = models.VectorContact.objects.all()
    serializer_class = serializers.VectorContactSerializerCreate


class VectorContactUpdate(generics.UpdateAPIView):
    queryset = models.VectorContact.objects.all()
    serializer_class = serializers.VectorContactSerializerUpdate
