# -*- coding: utf-8 -*-

import admin_tools

from django.utils.translation import ugettext_lazy as _

from admin_tools.dashboard import modules, AppIndexDashboard

from jmb.core.admin import dashboard as jmb_dashboard


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("organization"),
            'display': "tabs",
            'children': (OrganizationModels(), OtherOrganizationModels(), ContactModels(), OtherContactModels(), OtherModels(),)
        })
        super(DefaultDashboard, self).__init__(**kwargs)


class AppDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("organization"),
            'display': "tabs",
            'children': (OrganizationModels(), OtherOrganizationModels(), ContactModels(), OtherContactModels(), OtherModels(),)
        })
        super(AppDashboard, self).__init__(**kwargs)


class OrganizationModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("organizations"),
            'models': (
                'thux.organization.models.Organization',
            ),
        })
        super(OrganizationModels, self).__init__(**kwargs)


class OtherOrganizationModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("other organizations"),
            'models': (
                'thux.organization.models.OwnerOrganization',
                'thux.organization.models.CustomerOrganization',
                'thux.organization.models.SupplierOrganization',
                'thux.organization.models.VectorOrganization',
            ),
        })
        super(OtherOrganizationModels, self).__init__(**kwargs)


class ContactModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("contacts"),
            'models': (
                'thux.organization.models.Contact',
            ),
        })
        super(ContactModels, self).__init__(**kwargs)


class OtherContactModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("other contacts"),
            'models': (
                'thux.organization.models.OwnerContact',
                'thux.organization.models.CustomerContact',
                'thux.organization.models.SupplierContact',
                'thux.organization.models.WorkerContact',
                'thux.organization.models.VectorContact',
            ),
        })
        super(OtherContactModels, self).__init__(**kwargs)


class OtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("others"),
            'models': (
                'thux.organization.models.OrganizationGroup',
                'thux.organization.models.OrganizationType',
                'thux.organization.models.OrganizationForm',
                'thux.organization.models.Field',
                'thux.organization.models.ContactRole',
                'thux.organization.models.ContactTitle',
            ),
        })
        super(OtherModels, self).__init__(**kwargs)


class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin
jmb_dashboard.register_group(AppDashboard, 'thux.organization')
# Used in /admin/order
admin_tools.dashboard.register(DefaultAppDashboard, 'thux.organization')