# -*- coding: utf-8 -*-

import datetime

from django.conf import settings
from django.db.models import Sum


class StatementMixin(object):
    if 'jmb.statement' in settings.INSTALLED_APPS:
        def get_balance(self, date_s=None):
            """
            restituisce il saldo dell'Anagrafica
            alla data specificata
            """
            if not date_s:
                date_s = datetime.date.today()
            balance = self.statements.filter(date_s__lte=date_s).aggregate(
                Sum('amount')
            )
            return balance['amount__sum'] or 0

        def is_insolvent(self, date_s=None):
            """
            restituisce True o False se il cliente ha un saldo negativo alla data specificata
            """
            if not date_s:
                date_s = datetime.date.today()
            if self.get_balance(date_s) < 0:
                return True
            return False
